@@ -1,5 +1,5 @@
 #
-# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
+# Copyright © 2012–2022 Michal Čihař <michal@cihar.com>
 #
 # This file is part of Weblate translation-finder
 # <https://github.com/WeblateOrg/translation-finder>
@@ -31,6 +31,9 @@ EXCLUDES = {
     "__pycache__",
     "__MACOSX",
     ".deps",
+    ".venv",
+    ".env",
+    ".github",
 }
 
 
